@@ -9,11 +9,13 @@ _reg = get_registry()
 
 
 class TestRemoteObjects(unittest.TestCase):
+    
     def test_read_remote_properties(self):
         def_path_str = str(
             importlib.resources.files("tests").joinpath("definition/good_device.yaml")
         )
         with open(def_path_str) as device_description:
+
             obj = deserialize(yaml.safe_load(device_description))
             obj._channel = DummyChannel()
 
@@ -26,8 +28,16 @@ class TestRemoteObjects(unittest.TestCase):
             obj._channel.set_value(0.1)
             self.assertEqual(0.1 * _reg("ohm"), obj.motor.R)
 
+            obj.channel.set_value("lalala")
+            self.assertEqual(obj.nickname, "lalala")
+
             obj.controller.set_pos_vel_setpoints(0, 0)
 
+            obj._channel.write_on()
+            obj.nickname = "other"
+            obj._channel.write_off()
+            self.assertEqual(obj.nickname, "other")
+
     def test_remote_function_call(self):
         def_path_str = str(
             importlib.resources.files("tests").joinpath("definition/good_device.yaml")
